@@ -1,7 +1,7 @@
 /**
  * @file webpack的.atom文件loader
  */
-const atom = require('vip-server-renderer');
+const atom = require('atom-engine-compiler');
 
 module.exports = function (source) {
     return atom.compile({
@@ -11,4 +11,4 @@ module.exports = function (source) {
         },
         strip: true
     }).compiled.js;
-};
+};
\ No newline at end of file
